@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2000, 2008, 2010, 2012 Sergey Poznyakoff
+   Copyright (C) 1998-2019 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,6 +33,8 @@
 #endif
 
 #define DICO_DICT_PORT 2628
+#define DICO_DICT_PORT_STR "2628"
+
 /* Maximum size of I/O buffer as per RFC2229 */
 #define DICO_MAX_BUFFER 6144
 
@@ -51,17 +53,24 @@ typedef struct dico_result_struct *dico_result_t;
 typedef struct dico_strategy *dico_strategy_t;
 typedef struct dico_key *dico_key_t;
 
+typedef struct dicod_database dicod_database_t;
+
 #define DICO_SELECT_BEGIN 0
 #define DICO_SELECT_RUN   1
 #define DICO_SELECT_END   2
 typedef int (*dico_select_t) (int, dico_key_t, const char *);
 
-#define DICO_MODULE_VERSION 1
+#define DICO_MODULE_VERSION 3
 
-#define DICO_CAPA_NONE 0
-#define DICO_CAPA_NODB 0x0001
+#define DICO_CAPA_NONE       0
+#define DICO_CAPA_NODB       0x0001
+#define DICO_CAPA_INIT_EXT   0x0002
 #define DICO_CAPA_DEFAULT DICO_CAPA_NONE
 
+#define DICO_DBF_DEFAULT 0
+#define DICO_DBF_VIRTUAL 0x01
+#define DICO_DBF_MASK    0xffff
+
 struct dico_database_module {
     unsigned dico_version;
     unsigned dico_capabilities;
@@ -83,6 +92,12 @@ struct dico_database_module {
     size_t (*dico_compare_count) (dico_result_t rp);
     void (*dico_free_result) (dico_result_t rp);
     int (*dico_result_headers) (dico_result_t rp, dico_assoc_list_t hdr);
+    int (*dico_run_test) (int argc, char **argv);
+    char *(*dico_db_mime_header) (dico_handle_t hp);
+    dico_handle_t (*dico_init_db_ext) (const char *db, int argc, char **argv,
+				       void *extra);
+    int (*dico_db_flags) (dico_handle_t hp);
+    dicod_database_t *(*dico_result_db)(dico_result_t rp, size_t n);
 };
 
 #endif
