@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008, 2010 Sergey Poznyakoff
+   Copyright (C) 2008-2019 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,14 @@
 #define __dico_util_h
 
 char *dico_full_file_name(const char *dir, const char *file);
+size_t dico_string_trim(char *buf, size_t len, int (*pred)(int c));
 size_t dico_trim_nl(char *buf);
 size_t dico_trim_ws(char *buf);
+int dico_sort(void *base, size_t nmemb, size_t size,
+	      int (*comp)(const void *, const void *, void *),
+	      void *closure);
+void *dico_bsearch(void *key, const void *base, size_t nelem, size_t elsize,
+		   int (*comp) (const void *, const void *, void *),
+		   void *closure);
 
 #endif
